---
sidebar_label: alerts
title: soil.alerts.alerts
---

This package contains calls for the alerts system.

#### event

```python
def event(key: str, value: Any) -> Any
```

Creates an event.

#### alert

```python
def alert(alert_config: Dict) -> Any
```

Creates an alert.

